@@ -17,6 +17,10 @@ import hashlib
 import numpy
 import flair
 import langdetect
+from lightwood.helpers.text import tokenize_text
+import nltk
+from nltk.corpus import stopwords
+
 langdetect.DetectorFactory.seed = 0
 
 
@@ -25,6 +29,8 @@ def get_language_dist(data):
     lang_dist['Unknown'] = 0
     lang_probs_cache = dict()
     for text in data:
+        text = str(text)
+        text = ''.join([c for c in text if not c in string.punctuation])
         if text not in lang_probs_cache:
             try:
                 lang_probs = langdetect.detect_langs(text)
@@ -45,7 +51,7 @@ def analyze_sentences(data):
     """
     :param data: list of str
 
-    :returns: 
+    :returns:
     tuple(
         int: nr words total,
         dict: word_dist,
@@ -53,18 +59,25 @@ def analyze_sentences(data):
     )
     """
     nr_words = 0
-    word_dist = defaultdict(lambda: 0)
-    nr_words_dist = Counter()
+    word_dist = defaultdict(int)
+    nr_words_dist = defaultdict(int)
+    nltk.download('stopwords')
+    stop_words = set(stopwords.words('english'))
     for text in data:
-        sent = flair.data.Sentence(str(text))
-        nr_words_dist[len(sent)] += 1
-        nr_words += len(sent)
-        for tok in sent:
-            word = tok.text.strip(string.punctuation + '"\'«»')
-            word_dist[word] += 1
+        text = text.lower()
+        tokens = tokenize_text(text)
+        tokens_no_stop = [x for x in tokens if x not in stop_words]
+        nr_words_dist[len(tokens)] += 1
+        nr_words += len(tokens)
+        for tok in tokens_no_stop:
+            word_dist[tok] += 1
 
     return nr_words, dict(word_dist), dict(nr_words_dist)
 
+def shrink_word_dist(word_dist):
+    tiny_word_dist = dict(sorted(word_dist.items(), key=lambda x: x[1], reverse=True)[:min(50,len(word_dist))])
+    tiny_word_dist['other words'] = sum(word_dist.values()) - sum(tiny_word_dist.values())
+    return tiny_word_dist
 
 def word_tokenize(string):
     sep_tag = '{#SEP#}'
